@@ -15,7 +15,7 @@ type mockScriptRunner struct {
 }
 
 func (r *mockScriptRunner) Execute(
-	ctx context.Context, text string, env []string, args []string, dir, logPrefix string,
+	ctx context.Context, text string, env, args []string, dir, logPrefix string,
 ) error {
 	r.calls++
 	return r.returns
